import { AxiosError } from "axios"
import { client } from "./config";
import { GET_CURRENT_USER_REVIEW_LOCATION_URI, POST_REVIEW_LOCATION_URI } from "../constants/api";
import { IHttpResponse } from "src/types/common";

const initialState: IHttpResponse = {
  data: null,
  error: AxiosError,
  status: 0,
}

interface postReviewLocationReq {
  submitted_by: number,
  comments: string,
  score: number,
  is_from_critic: boolean,
  is_hided: boolean,
  location_id: number
}

async function postReviewLocation(req: postReviewLocationReq) {
  const newState = { ...initialState };
  try {
    const response = await client({ method: 'POST', url: POST_REVIEW_LOCATION_URI, data: req, withCredentials: true})
    newState.data = response.data
    newState.error = null
    return newState
  } catch (error) {
    newState.error = error
    throw(error)
  }
}

async function getCurrentUserLocationReviewService(location_id: number): Promise<IHttpResponse> {
  const newState = { ...initialState };
  try {
    const response = await client({ method: 'GET', url: `${GET_CURRENT_USER_REVIEW_LOCATION_URI}/${location_id}`, withCredentials: true})
    newState.data = response.data
    newState.error = null
    return newState
  } catch (err) {
    let error = err as AxiosError;
    newState.error = error
    newState.status = error.response?.status;
    throw(newState)
  }
}

export {
  postReviewLocation,
  getCurrentUserLocationReviewService,
}